@@ -1,6 +1,8 @@
 
 
 import psutil
+from twisted.internet import threads
+from twisted.internet.defer import inlineCallbacks
 from .base import SysInfoBase
 
 
@@ -15,13 +17,16 @@ class CpuInfo(SysInfoBase):
             'load_avg': self._load_avg
         }
 
+    @inlineCallbacks
     def _frequency(self):
-        result = psutil.cpu_freq()
+        result = yield threads.deferToThread(psutil.cpu_freq)
         return {
             'current': result.current,
             'min': result.min,
             'max': result.max
         }
 
+    @inlineCallbacks
     def _load_avg(self):
-        return psutil.getloadavg()
+        result = yield threads.deferToThread(psutil.getloadavg)
+        return result
